<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu" sourcelanguage="en">
  <context>
    <name>StartPage</name>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="42"/>
      <source>Start</source>
      <translation>Kezdő időpont</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="43"/>
      <source>Documents</source>
      <translation>Dokumentumok</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="44"/>
      <source>Help</source>
      <translation>Súgó</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="45"/>
      <source>Activity</source>
      <translation>Tevékenység</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="46"/>
      <source>Recent files</source>
      <translation>Legutóbbi fájlok</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="47"/>
      <source>Tip</source>
      <translation>Tipp</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="48"/>
      <source>Adjust the number of recent files to be shown here in menu Edit -&gt; Preferences -&gt; General -&gt; Size of recent file list</source>
      <translation>A legutóbbi fájlok száma beállítható a Szerkesztés -&gt; Beállítások -&gt; Általános -&gt; Legutóbbi fájlok listájának mérete menüpontban</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="49"/>
      <source>Examples</source>
      <translation>Példák</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="50"/>
      <source>General documentation</source>
      <translation>Általános dokumentáció</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="51"/>
      <source>User hub</source>
      <translation>Felhasználói csomópont</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="52"/>
      <source>This section contains documentation useful for FreeCAD users in general: a list of all the workbenches, detailed instructions on how to install and use the FreeCAD application, tutorials, and all you need to get started.</source>
      <translation>Ez a szakasz hasznos dokumentációkat tartalmaz a FreeCAD felhasználóknak: egy listát az összes munkafelületről, részletes utasításokat a telepítésről és a FreeCAD használatáról, útmutatók és minden ami a kezdéshez szükséges lehet.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="53"/>
      <source>Power users hub</source>
      <translation>Haladó felhasználói csomópont</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="54"/>
      <source>This section gathers documentation for advanced users and people interested in writing python scripts. You will also find there a repository of macros, instructions on how to install and use them, and more information about customizing FreeCAD to your specific needs.</source>
      <translation>Ez a szakasz a haladó felhasználóknak és a python szkriptek írásával kapcsolatban érdeklődőknek szóló dokumentációt tartalmazza. Ugyancsak itt található a makrók gyűjteménye, a hozzájuk kapcsolódó telepítési és használati útmutatók, illetve további információk a FreeCAD egyedi igényeknek megfelelő személyre szabásáról.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>Developers hub</source>
      <translation>Fejlesztői csomópont</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="55"/>
      <source>This section contains material for developers: How to compile FreeCAD yourself, how the FreeCAD source code is structured + how to navigate in it, how to develop new workbenches and/or embed FreeCAD in your own application.</source>
      <translation>Az a rész a fejlesztők számára tartalmaz anyagot: Hogyan kell összeállítani a FreeCAD-t, hogyan kell felépíteni a FreeCAD forráskódját + hogyan kell navigálni, új munkaállományokat fejleszteni és/vagy a FreeCAD-ot beépíteni a saját alkalmazásába.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="57"/>
      <source>Manual</source>
      <translation>Kézikönyv</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="58"/>
      <source>The FreeCAD manual is another, more linear way to present the information contained in this wiki. It is made to be read like a book, and will gently introduce you to many other pages from the hubs above. &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt;e-book versions&lt;/a&gt; are also available.</source>
      <translation>A FreeCAD kézikönyv egy másik, lineárisabb módja annak, hogy bemutassa a wikiban található információkat. Úgy készül, hogy olvasható, mint egy könyv, és finoman bemutatja Önnek sok más oldalon keresztül a fenti csomópontokat. A &lt;a href="https://www.gitbook.com/book/yorikvanhavre/a-freecad-manual/details"&gt; e-könyvverziók &lt;/a&gt; is elérhetők.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="59"/>
      <source>Workbenches documentation</source>
      <translation>Munkafelületek dokumentációja</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="60"/>
      <source>These are the help pages of all the workbenches currently installed on this computer.</source>
      <translation>A jelenleg telepített összes munkafelület súgói.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="61"/>
      <source>Getting help from the community</source>
      <translation>Segítségkérés a közösségtől</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="62"/>
      <source>The &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt; is a great place to get help from other FreeCAD users and developers. The forum has many sections for different types of issues and discussion subjects. If in doubt, post in the more general &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Help on using FreeCAD&lt;/a&gt; section.</source>
      <translation>A &lt;a href="http://forum.freecadweb.org"&gt;FreeCAD fórum&lt;/a&gt; egy nagyszerű hely, ahol segítséget kérhetsz FreeCAD felhasználóktól és fejlesztőktől. A fórumnak külön szakaszai foglalkoznak különböző fajta problémákkal és témákkal. Ha kétségeid vannak, hogy melyik szakaszba írj, akkor használd az általános &lt;a href="https://forum.freecadweb.org/viewforum.php?f=3"&gt;Segítség a FreeCAD használatában&lt;/a&gt; szakaszt.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="63"/>
      <source>If it is the first time you are posting on the forum, be sure to &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;read the guidelines&lt;/a&gt; first!</source>
      <translation>Ha ez az első alkalom, hogy a fórumba írsz, akkor mindenképp olvasd el előtte az &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=2264"&gt;Útmutatót!&lt;/a&gt;</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="64"/>
      <source>FreeCAD also maintains a public &lt;a href="https://www.freecadweb.org/tracker"&gt;bug tracker&lt;/a&gt; where anybody can submit bugs and propose new features. To avoid causing extra work and give the best chances to see your bug solved, make sure you read the &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt;bug submission guide&lt;/a&gt; before posting.</source>
      <translation>A FreeCAD fenntartja a nyilvános &lt;a href="https://www.freecadweb.org/tracker"&gt; hibakeresőt &lt;/a&gt;, ahol bárki beadhat hibákat és új szolgáltatásokat javasolhat. Annak elkerülése érdekében, hogy többlet munkát ne okozz, és a lehető legjobb eséllyel bírja a hiba megoldását, olvassa el a &lt;a href="https://forum.freecadweb.org/viewtopic.php?f=3&amp;t=5236"&gt; hibakeresési útmutatót &lt;/a&gt; kiküldetés előtt.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="65"/>
      <source>Available addons</source>
      <translation>Elérhető bővítmények</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="66"/>
      <source>Below is a list of available extra workbenches that can be added to your FreeCAD installation. Browse and install them from menu Tools -&gt; Addons manager. You can learn more about any of them by clicking the links below.</source>
      <translation>Alább látható az elérhető munkafelületek listája, amiket hozzáadhatsz a FreeCAD-hez. A menüben az Eszközök -&gt; Bővítmények kezelése menüpontban böngészhetsz köztük és telepítheted őket. Bármelyikről többet tudhatsz meg, ha az alábbi linkekre kattintasz.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="67"/>
      <source>If not bundled with your FreeCAD version, install the FreeCAD documentation package to get documentation hubs, workbench help and individual command documentation without an internet connection.</source>
      <translation>Ha a te FreeCAD verziód nem tartalmazta, akkor telepítsd a FreeCAD dokumentáció csomagot, amivel internet nélkül is elérheted a dokumentációs csomópontokat, a munkafelületek súgóit illetve az egyes parancsokhoz tartozó dokumentációt.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="68"/>
      <source>Cannot fetch information from GitHub. &lt;a href="EnableDownload.py"&gt;Authorize FreeCAD to access the internet&lt;/a&gt; and reload the Start page.</source>
      <translation>Nem kérhető le információ a GitHub-ról. &lt;a href="EnableDownload.py"&gt;Engedélyezd, hogy a FreeCAD hozzáférjen az internethez,&lt;/a&gt; majd töltsd újra a Kezdőlapot.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="69"/>
      <source>Recent commits</source>
      <translation>Legutóbbi bejegyzések</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="70"/>
      <source>Below are the latest changes added to the &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt;FreeCAD source code&lt;/a&gt;. These changes might not reflect yet in the FreeCAD version that you are currently running. Check the &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt;available options&lt;/a&gt; if you wish to obtain a development version.</source>
      <translation>Az alábbiakban láthatók a &lt;a href="http://github.com/FreeCAD/FreeCAD/"&gt; FreeCAD forráskódjának &lt;/a&gt; legfrissebb módosításai. Ezek a változások még nem tükrözik a jelenleg futó FreeCAD verziót. Ellenőrizze a &lt;a href="https://www.freecadweb.org/wiki/Downloads"&gt; elérhető opciókat &lt;/a&gt;, ha fejlesztési verziót szeretne kapni.</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>See all commits on github</source>
      <translation>Tekintse meg az összes github közzétételt</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="71"/>
      <source>You can configure a custom folder to display here in menu Edit -&gt; Preferences -&gt; Start -&gt; Show additional folder</source>
      <translation>Az ebben a menüben megjelenítendő egyéni mappát beállíthatod a Szerkesztés -&gt; Beállítások -&gt; Start -&gt; További mappa menüpontban</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="73"/>
      <source>version</source>
      <translation>verzió</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="74"/>
      <source>build</source>
      <translation>kiadás</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="75"/>
      <source>Create new...</source>
      <translation>Új létrehozása...</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="76"/>
      <source>Unknown</source>
      <translation>Ismeretlen</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="77"/>
      <source>Forum</source>
      <translation>Fórum</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="78"/>
      <source>The latest posts on the &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD forum&lt;/a&gt;:</source>
      <translation>Legújabb hozzászólások a &lt;a href="https://forum.freecadweb.org"&gt;FreeCAD fórum&lt;/a&gt;on:</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="79"/>
      <source>To open any of the links above in your desktop browser, Right-click -&gt; Open in external browser</source>
      <translation>A fenti hivatkozások egyikének az asztali böngészőben megnyitásához kattintson a jobb gombbal a -&gt; Nyissa meg a külső böngészőben</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="80"/>
      <source>Creation date</source>
      <translation>Létrehozás dátuma</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="81"/>
      <source>Last modification</source>
      <translation>Utolsó módosítás</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Notes</source>
      <translation>Megjegyzések</translation>
    </message>
    <message>
      <location filename="../../../StartPage/TranslationTexts.py" line="82"/>
      <source>Open start page preferences</source>
      <translation>Kezdőlap beállításainak megnyitása</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Command.cpp" line="58"/>
      <location filename="../../Workbench.cpp" line="65"/>
      <source>Start page</source>
      <translation>Kezdőlap</translation>
    </message>
  </context>
  <context>
    <name>CmdStartPage</name>
    <message>
      <location filename="../../Command.cpp" line="44"/>
      <source>Start</source>
      <translation>Kezdő időpont</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="45"/>
      <source>Start Page</source>
      <translation>Kezdő oldal</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="46"/>
      <source>Displays the start page in a browser view</source>
      <translation>Megnyitja a kezdő oldalt egy böngészőnézetben</translation>
    </message>
  </context>
  <context>
    <name>DlgStartPreferences</name>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="14"/>
      <source>Start page options</source>
      <translation>Kezdő oldal lehetőségek</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="20"/>
      <source>Start page template</source>
      <translation>Kezdő oldal sablon</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="26"/>
      <source>An optional HTML template that will be used instead of the default start page.</source>
      <translation>Egy HTML sablon lehetőség, meylet az alapértelmezett kezdő oldal helyett fogja használni.</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="42"/>
      <source>Contents</source>
      <translation>Tartalom</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="48"/>
      <source>Show forum</source>
      <translation>Fórum mutatása</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="55"/>
      <source>Show examples folder contents</source>
      <translation>Mutassa a példák mappa tartalmát</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="62"/>
      <source>Show additional folder</source>
      <translation>Mutassa a kiegészítő mappákat</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="69"/>
      <source>If you want the examples to show on the first page</source>
      <translation>Ha szeretné a példákat az első oldalon megmutatni</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="91"/>
      <source>If this is checked, the latest posts from the FreeCAD forum will be displayed on the Activity tab</source>
      <translation>Ha bejelölt, a legutóbbi FreeCAD fórum bejegyzéseket kijelzi a Tevékenység táblázatban</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="110"/>
      <source>An optional custom folder to be displayed at the bottom of the first page</source>
      <translation>Egy további személyre szabható mappát lehet kijelezni az első oldal alján</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="126"/>
      <source>Show notepad</source>
      <translation>Jegyzettömb megjelenítése</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="133"/>
      <source>Shows a notepad next to the file thumbnails, where you can keep notes across FreeCAD sessions</source>
      <translation>Jegyzettömb megjelenítése a fájlok bélyegképei mellett, ahová feljegyzéseket készíthet a FreeCAD szakaszain keresztül</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="155"/>
      <source>Fonts and colors</source>
      <translation>Betűtípusok és színek</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="167"/>
      <source>The background of the main start page area</source>
      <translation>A fő kezdő oldal területének a háttere</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="187"/>
      <source>Background color</source>
      <translation>Háttér szín</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="199"/>
      <source>in FreeCAD</source>
      <translation>FreeCAD-ban</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="218"/>
      <source>In external browser</source>
      <translation>Külső böngészőben</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="236"/>
      <source>Background color gradient down</source>
      <translation>Háttér színátmenet halványítás</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="249"/>
      <source>The color of the version text</source>
      <translation>A verzió szövegének színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="269"/>
      <source>Link color</source>
      <translation>Kapcsolat színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="276"/>
      <source>An optional image to display as background</source>
      <translation>Egy lehetséges ábra a háttérképnek</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="289"/>
      <source>If this is checked, if a style sheet is specified in General preferences, it will be used and override the colors below</source>
      <translation>Ha bejelölt, ha az általános testreszabásokban egy stílus lapot meghatározott, ennek használatával felülírja az alul található színeket</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="308"/>
      <source>Page background color</source>
      <translation>Oldal háttérszíne</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="321"/>
      <source>The color of the text on the main pages</source>
      <translation>A fő oldalak szöveg színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="341"/>
      <source>Background image</source>
      <translation>Háttérkép</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="348"/>
      <source>Page text color</source>
      <translation>Oldal szöveg színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="361"/>
      <source>The color of the links</source>
      <translation>A hivatkozások színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="387"/>
      <source>The background color of the boxes inside the pages</source>
      <translation>Az oldalon levő téglatestek háttér színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="407"/>
      <source>Box background color</source>
      <translation>Téglatest háttérszíne</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="420"/>
      <source>The background color behind the panels</source>
      <translation>Panelek mögötti háttérszín</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="449"/>
      <source>The down gradient for the background color (currently unsupported)</source>
      <translation>A háttérszín halványítása (jelenleg nem támogatott)</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="472"/>
      <source>Open links</source>
      <translation>Nyitott kapcsolatok</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="479"/>
      <source>Background text color</source>
      <translation>Háttér szöveg színe</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="486"/>
      <source>Use FreeCAD style sheet</source>
      <translation>FreeCAD stíluslap használata</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="493"/>
      <source>Font family</source>
      <translation>Betűkészlet</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="502"/>
      <source>The font family to use on the start page. Can be a font name or a comma-separated series of fallback fonts</source>
      <translation>A kezdő oldalon használni kívánt betűcsalád. Állhat egy betűtípus nevéből vagy vesszővel elválasztott visszatérő betűtípus sorozatából</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="508"/>
      <source>Arial,Helvetica,sans</source>
      <translation>Arial, Helvetica, sans</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="521"/>
      <source>The base font size to use for all texts of the Start page</source>
      <translation>Alap betűméretet a kezdő oldal összes szövegének használatához</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="524"/>
      <source>px</source>
      <translation>px</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="542"/>
      <source>Use gradient for New File icon</source>
      <translation>Színátmenet használata új fájl ikonjára</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="568"/>
      <source>Options</source>
      <translation>Beállítások</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="577"/>
      <source>Should the start page be closed after loading?</source>
      <translation>A start oldalt zárja be a betöltődés után?</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="596"/>
      <source>Switch workbench after loading</source>
      <translation>Munkafelületre váltás a betöltés után</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="603"/>
      <source>Close start page after loading</source>
      <translation>Kezdő oldal bezárása a betöltés után</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="610"/>
      <source>Close &amp; switch on file open</source>
      <translation>Bezárás &amp; váltás a fájl megnyitásakor</translation>
    </message>
    <message>
      <location filename="../../DlgStartPreferences.ui" line="617"/>
      <source>If FreeCAD is started by opening a file, apply the two settings above</source>
      <translation>Ha a FreeCAD egy fájl megnyitásával indul, alkalmazza a fenti két beállítást</translation>
    </message>
  </context>
</TS>
